@@ -1,7 +1,7 @@
 <?php
 /**
  * ezcConsoleArgumentTest class.
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -9,9 +9,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -27,7 +27,7 @@
 
 /**
  * Test suite for ezcConsoleArgument class.
- * 
+ *
  * @package ConsoleTools
  * @subpackage Tests
  */
@@ -39,10 +39,6 @@ class ezcConsoleArgumentTest extends ezcTestCase
 		return new PHPUnit\Framework\TestSuite( "ezcConsoleArgumentTest" );
 	}
 
-    protected function setUp()
-    {
-    }
-
     public function testConstructorSuccess()
     {
         $arg = new ezcConsoleArgument(
@@ -118,7 +114,7 @@ class ezcConsoleArgumentTest extends ezcTestCase
     public function testSetAccessSuccess()
     {
         $arg = new ezcConsoleArgument( "testname" );
-        
+
         $this->assertSetProperty(
             $arg,
             "type",
